@@ -1,6 +1,6 @@
 /*
 
-  Copyright (C) 2003 - 2012  Razvan Cojocaru <rzvncj@gmail.com>
+  Copyright (C) 2003 - 2013  Razvan Cojocaru <rzvncj@gmail.com>
    XML-RPC/Context ID code contributed by Eamon Millman / PCI Geomatics
   <millman@pcigeomatics.com>
   Tree control icons code (and the icons) contributed by Fritz Elfert
@@ -49,13 +49,14 @@
 #define OPEN_HELP _("Open a CHM book.")
 #define FONTS_HELP _("Change fonts.")
 #define PRINT_HELP _("Print the page currently displayed.")
-#define CONTENTS_HELP _("On or off?")
+#define CONTENTS_HELP _("Toggle table of contents.")
 #define HOME_HELP _("Go to the book's start page.")
 #define FORWARD_HELP _("Go forward in history. Per book.")
 #define BACK_HELP _("Back to the last visited page. Per book.")
 #define ABOUT_HELP _("About the program.")
 #define COPY_HELP _("Copy selection.")
 #define FIND_HELP _("Find word in page.")
+#define FULLSCREEN_HELP _("Toggle fullscreen mode.")
 #define CLOSETAB_HELP _("Close the current tab")
 #define NEWTAB_HELP _("Open a new tab")
 #define REGISTER_EXTENSION_HELP _("Associate the .chm file extension with xCHM.")
@@ -132,14 +133,14 @@ CHMFrame::CHMFrame(const wxString& title, const wxString& booksDir,
 	: wxFrame(NULL, -1, title, pos, size),
 	  _tcl(NULL), _sw(NULL), _menuFile(NULL), _tb(NULL), _ep(NULL),
 	  _nb(NULL), _cb(NULL), _csp(NULL), _cip(NULL), _openPath(booksDir), 
-	  _normalFonts(NULL), _fixedFonts(NULL), _normalFont(normalFont), 
+	  _normalFonts(NULL), _fixedFonts(NULL), _normalFont(normalFont),
 	  _fixedFont(fixedFont), _fontSize(fontSize), _bookmarkSel(true),
 	  _bookmarksDeleted(false), _sashPos(sashPosition),
 	  _fullAppPath(fullAppPath), _loadTopics(loadTopics),
-	  _loadIndex(loadIndex)
+	  _loadIndex(loadIndex), _fullScreen(false)
 {
 #	if wxUSE_ACCEL
-	const int NO_ACCELERATOR_ENTRIES = 5;
+	const int NO_ACCELERATOR_ENTRIES = 6;
 	wxAcceleratorEntry entries[NO_ACCELERATOR_ENTRIES];
 
 	entries[0].Set(wxACCEL_CTRL, (int) 'F', ID_FindInPage);
@@ -147,6 +148,7 @@ CHMFrame::CHMFrame(const wxString& title, const wxString& booksDir,
 	entries[2].Set(wxACCEL_CTRL, (int) ']', ID_Forward);
 	entries[3].Set(wxACCEL_CTRL, (int) '[', ID_Back);
 	entries[4].Set(wxACCEL_CTRL, WXK_F4, ID_CloseTab);
+	entries[5].Set(wxACCEL_CTRL, 'Q', ID_Quit);
 
 	wxAcceleratorTable accel(NO_ACCELERATOR_ENTRIES, entries);
 	SetAcceleratorTable(accel);
@@ -164,7 +166,7 @@ CHMFrame::CHMFrame(const wxString& title, const wxString& booksDir,
 	SetIcon(wxIcon(xchm_32_xpm));
 	SetMenuBar(CreateMenu());
 
-	_tb = CreateToolBar(wxTB_HORIZONTAL | wxTB_TEXT
+	_tb = CreateToolBar(wxTB_HORIZONTAL | wxTB_TEXT 
 #if defined __WXMSW__ || defined __WXGTK__			
 			   | wxTB_FLAT | wxTB_DOCKABLE
 #endif
@@ -426,22 +428,32 @@ void CHMFrame::OnFind(wxCommandEvent& event)
 	_nbhtml->GetCurrentPage()->OnFind(event);
 }
 
+
 void CHMFrame::OnCloseTab(wxCommandEvent& event)
 {
 	_nbhtml->OnCloseTab(event);
 }
 
+
 void CHMFrame::OnNewTab(wxCommandEvent& event)
 {
 	_nbhtml->OnNewTab(event);
 }
 
+
 void CHMFrame::OnCopySelection(wxCommandEvent& event)
 {
 	_nbhtml->GetCurrentPage()->OnCopy(event);
 }
 
 
+void CHMFrame::OnFullScreen(wxCommandEvent& WXUNUSED(event))
+{
+	_fullScreen = !_fullScreen;
+	ShowFullScreen(_fullScreen, wxFULLSCREEN_ALL);
+}
+
+
 void CHMFrame::OnAddBookmark(wxCommandEvent& WXUNUSED(event))
 {
 	wxTreeItemId id = _tcl->GetSelection();
@@ -640,7 +652,7 @@ void CHMFrame::UpdateCHMInfo()
 		return;
 
 	wxWindowDisabler wwd;
-	wxBusyInfo wait(_("Loading, please wait.."));
+	wxBusyInfo wait(_("Loading, please wait.."), this);
 
 	wxString filename = chmf->ArchiveName();
 	if(!filename.IsEmpty()) {		
@@ -728,11 +740,8 @@ void CHMFrame::UpdateCHMInfo()
                         + title;
 
 		SetTitle(titleBarText);
-		_nbhtml->GetCurrentPage()->SetRelatedFrame(this, titleBarText);
 	} else {
 		SetTitle(wxT("xCHM v. ") wxT(VERSION));
-		_nbhtml->GetCurrentPage()
-			->SetRelatedFrame(this, wxT("xCHM v. ") wxT(VERSION));
 	}
 	
 	// if we have contents..
@@ -811,8 +820,13 @@ wxMenuBar* CHMFrame::CreateMenu()
 	menuEdit->Append(ID_CloseTab, _("&Close tab\tCtrl-W"), CLOSETAB_HELP);
 	menuEdit->Append(ID_NewTab, _("&New tab\tCtrl-T"), NEWTAB_HELP);
 
+	wxMenu *menuView = new wxMenu;
+	menuView->Append(ID_FullScreen, _("Toggle &fullscreen\tF11"),
+			 FULLSCREEN_HELP);
+
 	wxMenuBar *menuBar = new wxMenuBar;
 	menuBar->Append(_menuFile, _("&File"));
+	menuBar->Append(menuView, _("&View"));
 	menuBar->Append(menuEdit, _("&Edit"));
 	menuBar->Append(menuHistory, _("Hi&story"));
 	menuBar->Append(menuHelp, _("&Help"));
@@ -997,6 +1011,7 @@ namespace {
 #include <htmoptns.xpm>
 #include <copy.xpm>
 #include <find.xpm>
+#include <fullscreen.xpm>
 
 } // namespace
 
@@ -1020,6 +1035,11 @@ bool CHMFrame::InitToolBar(wxToolBar *toolbar)
 			wxBitmap(find_xpm), FIND_HELP);
 	
 	toolbar->AddSeparator();
+	
+	toolbar->AddTool(ID_FullScreen, _("Fullscreen"),
+			 wxBitmap(fullscreen_xpm), FULLSCREEN_HELP);
+
+	toolbar->AddSeparator();
 
 	toolbar->AddTool(ID_Back, _("Back"), wxBitmap(back_xpm), BACK_HELP);
 	toolbar->AddTool(ID_Forward, _("Forward"), wxBitmap(forward_xpm), 
@@ -1042,6 +1062,16 @@ void CHMFrame::AddHtmlView(const wxString& path, const wxString& link)
 }
 
 
+void CHMFrame::ToggleFullScreen(bool onlyIfFullScreenOn)
+{
+	if(onlyIfFullScreenOn && !_fullScreen)
+		return;
+
+	wxCommandEvent dummy;
+	OnFullScreen(dummy);
+}
+
+
 BEGIN_EVENT_TABLE(CHMFrame, wxFrame)
 	EVT_MENU(ID_Quit,  CHMFrame::OnQuit)
 	EVT_MENU(ID_About, CHMFrame::OnAbout)
@@ -1060,6 +1090,7 @@ BEGIN_EVENT_TABLE(CHMFrame, wxFrame)
 	EVT_MENU(ID_CloseTab, CHMFrame::OnCloseTab)
 	EVT_MENU(ID_NewTab, CHMFrame::OnNewTab)
 	EVT_MENU(ID_CopySelection, CHMFrame::OnCopySelection)
+	EVT_MENU(ID_FullScreen, CHMFrame::OnFullScreen)
 	EVT_BUTTON(ID_Add, CHMFrame::OnAddBookmark)
 	EVT_BUTTON(ID_Remove, CHMFrame::OnRemoveBookmark)
 	EVT_TREE_SEL_CHANGED(ID_TreeCtrl, CHMFrame::OnSelectionChanged)
