@@ -1,6 +1,6 @@
 /*
 
-  Copyright (C) 2003 - 2012  Razvan Cojocaru <rzvncj@gmail.com>
+  Copyright (C) 2003 - 2013  Razvan Cojocaru <rzvncj@gmail.com>
  
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -40,6 +40,7 @@ enum {
 	ID_PopupForward,
 	ID_PopupBack,
 	ID_PopupFind,
+	ID_PopupFullScreen,
 	ID_OpenInNewTab,
 };
 
@@ -147,6 +148,10 @@ protected:
 
 	//! Called when the user selects 'Save link as' from the popup menu.
 	void OnOpenInNewTab(wxCommandEvent& event);
+
+	//! Called when the 'Toggle fullscreen' is selected from the popup menu.
+	void OnToggleFullScreen(wxCommandEvent& event);
+
 protected:	
 	//! Called when the user right clicks the HTML window.
 	void OnRightClick(wxMouseEvent& event);
@@ -162,7 +167,7 @@ private:
 	wxString GetPrefix(const wxString& location) const;
 	
 private:
-	wxTreeCtrl* _tcl;
+	wxTreeCtrl *_tcl;
 	bool _syncTree;
 	bool _found;
 	wxMenu *_menu;
