@@ -1,6 +1,6 @@
 /*
 
-  Copyright (C) 2003 - 2012  Razvan Cojocaru <rzvncj@gmail.com>
+  Copyright (C) 2003 - 2013  Razvan Cojocaru <rzvncj@gmail.com>
  
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -137,11 +137,8 @@ size_t CHMInputStream::OnSysRead(void *buffer, size_t bufsize)
 	return bufsize;
 }
 
-#ifdef __WXMSW__
+
 wxFileOffset CHMInputStream::OnSysSeek(wxFileOffset seek, wxSeekMode mode)
-#else
-off_t CHMInputStream::OnSysSeek(off_t seek, wxSeekMode mode)
-#endif
 {
 	switch(mode) {
 	case wxFromCurrent:
